# What's Changed

1. perf: 优化 WebChat 等组件的 UI 风格
2. fix: 修复 4.1.6 版本可能无法点击更新按钮的问题
3. fix: 修复更新开发版的时候，可能无法同时更新 WebUI 的问题
4. feat: 支持在「对话数据」页批量删除对话
5. fix: 修复部分错误地显示「格式校验未通过」的问题
6. perf: WebChat 支持手动填写模型名称
